##  Data Insights
To navigate to specific datasets for a deeper analysis, select them on the chart. Examine the detailed chart and use these insights to understand why the KPI needs improvement. Based on this information, make data-driven decisions.
For example, the KPI "Technical fit of applications" in the image below provides insights for the selected "CEO" dataset. The chart on the right displays applications with unreasonable or inappropriate technical fit compared to the last quarter.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0e3afe4dfc7b4a1f874df6105d3f6c45_LowRes.png)
Data Insights Are Displayed on the Right
